#define MFBPOLYGLYPHBLT xf1bppPolyGlyphBltInvert
#define OPEQ ^=
#include "mfbmap.h"
#include "../../../mfb/mfbplygblt.c"
